@@ -6,8 +6,9 @@ from .pyDriver import GSQL_Client, ExceptionRecursiveRet, ExceptionCodeRet,REST_
 
 class Client():
     def __init__(self, server_ip="127.0.0.1", username="tigergraph", password="tigergraph", cacert=""
-                 ,version="", commit="",restPort="14240",gsPort="9000",protocol="https"
+                 ,version="3.0.5", commit="",restPort="9000",gsPort="14240",protocol="https"
                  ,graph="MyGraph",token=""):
-        self.Rest = REST_Client(server_ip=server_ip,protocol=protocol,restPort=restPort,token=token)
+        self.Rest = REST_Client(server_ip=server_ip,protocol=protocol,restPort=restPort,token=token
+                                , username=username, password=password, cacert=cacert)
         self.Gsql = GSQL_Client(server_ip=server_ip, username=username, password=password, cacert=cacert
                            ,version=version, commit=commit,graph=graph,gsPort=gsPort,protocol=protocol)
\ No newline at end of file
